#TODO: Fix error message with processing plug-in in regards to pyspatialite

# Shared lib calls exit
# https://hub.qgis.org/issues/2854

# libspatialite is present for PPC and PPC64 in Fedora and EL7, but not in older EL
%global configure_with_spatialite -D WITH_QSPATIALITE:BOOL=TRUE
%if (0%{?rhel} <= 6 && !0%{?fedora})
%ifarch ppc ppc64
%global configure_with_spatialite -D WITH_QSPATIALITE:BOOL=FALSE
%endif
%endif

#TODO: Run test suite (see debian/rules)

Name:           qgis
Version:        2.18.14
Release:        1%{?dist}
Summary:        A user friendly Open Source Geographic Information System
Group:          Applications/Engineering

# http://hub.qgis.org/issues/3789
License:        GPLv3+ with exceptions
URL:            http://www.qgis.org

Source0:        http://qgis.org/downloads/%{name}-%{version}.tar.bz2
# The used sources were released as a tarball, the below is only for work in progress
#git archive --format=tar --prefix=qgis-1.8.0/ master | bzip2 >../qgis-1.8.0.tar.gz

# Sample configuration files for QGIS server
Source2:        %{name}-server-httpd.conf
Source4:        %{name}-server-README.fedora

# MIME definitions
# Based on debian/qgis.xml but excluding already defined or proprietary types
Source5:        %{name}-mime.xml
# Fix builds on 64-bit machines
# https://hub.qgis.org/issues/15602
# https://github.com/qgis/QGIS/commit/718581ffb12b723f9a3c0ae01b7ec2d8aed9d4bb.patch
Patch0:         %{name}-lib64.patch

# Some plug-ins need Pyspatialite (bundled)
# The license is not totally clear, see:
# http://code.google.com/p/pyspatialite/issues/detail?id=3
# It also is sort of a fork of pysqlite, which is not elegant.
#
# F20 and up instead allow for loadable sqlite extensions in Python:
# https://bugzilla.redhat.com/show_bug.cgi?id=1066708

BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  expat-devel
BuildRequires:  fcgi-devel
BuildRequires:  flex bison
BuildRequires:  gdal-devel
BuildRequires:  geos-devel
BuildRequires:  grass-devel
BuildRequires:  gsl-devel

%ifarch ppc ppc64
%if (0%{?fedora} || 0%{?rhel} > 6)
BuildRequires:  libspatialite-devel
%endif
%else
BuildRequires:  libspatialite-devel
%endif

BuildRequires:  postgresql-devel
BuildRequires:  proj-devel
BuildRequires:  PyQt4-devel
# PyQwt doesn't support qwt6, so just turn it off for now on RHEL
%if 0%{?fedora}
BuildRequires:  PyQwt-devel
%endif
BuildRequires:  python2-devel
# qca2 is a virtual provides of qca. Put here to make things easier for EPEL!
BuildRequires:  qca2-devel
BuildRequires:  qextserialport-devel
BuildRequires:  qjson-devel
BuildRequires:  qscintilla-devel
BuildRequires:  qscintilla-python
BuildRequires:  qscintilla-python-devel
BuildRequires:  qt4-devel
#BuildRequires:  qt-mobility-devel
BuildRequires:  qt4-webkit-devel
BuildRequires:  qwt-devel
BuildRequires:  qwtpolar-devel
BuildRequires:  sip-devel > 4.7
BuildRequires:  spatialindex-devel
BuildRequires:  sqlite-devel

# Fails to build with QT_MOBILITY
#http://hub.qgis.org/issues/7753
#BuildRequires:  qt-mobility-devel

# Enable for tests
#BuildRequires:  xorg-x11-server-Xvfb

Requires:       gpsbabel
# As found in BZ#1396818
Requires:       qca-ossl

# We don't want to provide private Python extension libs
%if (0%{?fedora} || 0%{?rhel} > 6)
%global __provides_exclude_from ^(%{python_sitearch}|%{_libdir}/%{name}/plugins)/.*\.so(\.%{version})?$
%endif

%if 0%{?rhel} == 6
%{?filter_setup:
%filter_provides_in ^(%{python_sitearch}|%{_libdir}/%{name}/plugins)/.*\.so(\.%{version})?$
%filter_setup
}
%endif

%description
Geographic Information System (GIS) manages, analyzes, and displays
databases of geographic information. QGIS supports shape file
viewing and editing, spatial data storage with PostgreSQL/PostGIS, projection
on-the-fly, map composition, and a number of other features via a plugin
interface. QGIS also supports display of various geo-referenced raster and
Digital Elevation Model (DEM) formats including GeoTIFF, Arc/Info ASCII Grid,
and USGS ASCII DEM.

%package devel
Summary:        Development Libraries for the QGIS
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
Development packages for QGIS including the C header files.

%package grass
Summary:        GRASS Support Libraries for QGIS
Group:          Applications/Engineering
Requires:       %{name}%{?_isa} = %{version}-%{release}

# The plug-in requires more than just the grass-libs.
# This questions the sense of the libs package.
# WARNING: Rebuild QGIS whenever a new version of GRASS is shipped! Even though
# the soname might stay the same, it won't work anymore.
#http://hub.qgis.org/issues/5274
Requires:       grass%{?_isa} = %{grass_version}

%description grass
GRASS plugin for QGIS required to interface with the GRASS system.

%package -n python2-qgis
%{?python_provide:%python_provide python2-qgis}
# Remove before F30
Provides: %{name}-python = %{version}-%{release}
Provides: %{name}-python%{?_isa} = %{version}-%{release}
Obsoletes: %{name}-python < %{version}-%{release}
Summary:        Python integration and plug-ins for QGIS
Group:          Applications/Engineering
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       gdal-python
Requires:       PyQt4-webkit
Requires:       python-httplib2
Requires:       python-jinja2
Requires:       python-matplotlib
Requires:       python-OWSLib
Requires:       python-psycopg2
Requires:       python-pygments
Requires:       python-six
Requires:       PyYAML
Requires:       qscintilla-python
%{?_sip_api:Requires: sip-api(%{_sip_api_major}) >= %{_sip_api}}

%description -n python2-qgis
Python integration and plug-ins for QGIS.

%package server
Summary:        FCGI-based OGC web map server
Group:          Applications/Engineering
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       mod_fcgid
Provides: mapserver = %{version}-%{release}
Obsoletes: mapserver < 2.8.1-1

%description server
This FastCGI OGC web map server implements OGC WMS 1.3.0 and 1.1.1.
The services are prepared as regular projects in QGIS. They're rendered using
the QGIS libraries. The server also supports SLD (Styled Layer Descriptor)
for styling. Sample configurations for Httpd and Lighttpd are included.

Please refer to %{name}-server-README.fedora for details!

%prep
%setup -q
%patch0 -p1 -b .lib64

# Remove executable permissions from source code files
find . \( -name "*.cpp" -o -name "*.h" \) -type f -perm /111 -execdir chmod -x {} \+

# Readme file for QGIS server configuration and Lighttpd example
install -pm0644 %{SOURCE4} .

# Delete bundled libs
rm -rf src/core/spatialite/
rm -rf src/core/gps/qwtpolar-{0.1,1.0}/
rm -rf src/core/gps/qextserialport/
rm -rf src/core/gps/qextserialport/
rm -rf "python/ext-libs/!(CMakeLists.txt|tests)"

rm -rf src/plugins/dxf2shp_converter/
sed -i '/dxf2shp_converter/d' src/plugins/CMakeLists.txt

gzip ChangeLog


%build

# Necessary for the test suite
#export LD_LIBRARY_PATH=%{_builddir}%{name}-%{version}/output/%{_lib}

#TODO: If for EPEL (osgearth, touch)
#Info: TOUCH needs Qt >= 4.5
%cmake \
      %{_cmake_skip_rpath} \
      -D QGIS_LIB_SUBDIR=%{_lib} \
      -D QGIS_MANUAL_SUBDIR=/share/man \
      -D QGIS_CGIBIN_SUBDIR=%{_libexecdir}/%{name} \
      -D WITH_BINDINGS:BOOL=TRUE \
      -D WITH_GRASS:BOOL=TRUE \
      -D WITH_GRASS7:BOOL=TRUE \
      -D GRASS_PREFIX=%{_libdir}/grass \
      -D WITH_CUSTOM_WIDGETS:BOOL=TRUE \
      -D BINDINGS_GLOBAL_INSTALL:BOOL=TRUE \
      -D ENABLE_TESTS:BOOL=FALSE \
      -D WITH_INTERNAL_DATEUTIL:BOOL=FALSE \
      -D WITH_INTERNAL_HTTPLIB2:BOOL=FALSE \
      -D WITH_INTERNAL_JINJA2:BOOL=FALSE \
      -D WITH_INTERNAL_MARKUPSAFE:BOOL=FALSE \
      -D WITH_INTERNAL_OWSLIB:BOOL=FALSE \
      -D WITH_INTERNAL_PYGMENTS:BOOL=FALSE \
      -D WITH_INTERNAL_PYTZ:BOOL=FALSE \
      -D WITH_INTERNAL_QEXTSERIALPORT:BOOL=FALSE \
      -D WITH_INTERNAL_QWTPOLAR:BOOL=FALSE \
      -D WITH_INTERNAL_SIX:BOOL=FALSE \
      -D WITH_INTERNAL_YAML:BOOL=FALSE \
      -D WITH_PYSPATIALITE:BOOL=FALSE \
      -D WITH_SERVER:BOOL=TRUE \
      -D WITH_TOUCH:BOOL=TRUE \
      %{configure_with_spatialite} \
      .
      #-D WITH_QTMOBILITY:BOOL=TRUE \
      # Doesn't build, as of 2.10, known issue
      #-D WITH_GLOBE:BOOL=TRUE

# Parallel build appears to occasionally result in build failures
# (UI form headers generated too late)
# TODO: Re-check with QGIS-3.0
make


%install
# Necessary for the test suite
#export LD_LIBRARY_PATH=%{_builddir}%{name}-%{version}/output/%{_lib}
make install DESTDIR=%{buildroot}

# Install desktop file without connecting proprietary file types
desktop-file-install \
%if (0%{?rhel} && 0%{?rhel} < 7)
    --vendor="fedora" \
%endif
    --remove-mime-type="application/x-raster-ecw" \
    --remove-mime-type="application/x-raster-mrsid" \
    --dir=%{buildroot}%{_datadir}/applications \
    debian/qgis.desktop

desktop-file-install --dir=%{buildroot}%{_datadir}/applications \
    debian/qbrowser.desktop

# Install MIME type definitions
install -d %{buildroot}%{_datadir}/mime/packages
install -pm0644 %{SOURCE5} \
    %{buildroot}%{_datadir}/mime/packages/%{name}.xml

# Install application and MIME icons
for size in 8x8 16x16 22x22 24x24 32x32 36x36 42x42 48x48 64x64 72x72 80x80 96x96 128x128 192x192 256x256 512x512; do
    install -pd %{buildroot}%{_datadir}/icons/hicolor/$size/apps
    install -pm0644 debian/%{name}-icon$size.png %{buildroot}%{_datadir}/icons/hicolor/$size/apps/qgis.png
    install -pm0644 debian/qbrowser-icon$size.png %{buildroot}%{_datadir}/icons/hicolor/$size/apps/qbrowser.png
done

for size in 8x8 16x16 22x22 24x24 32x32 36x36 42x42 48x48 64x64 72x72 80x80 96x96 128x128; do
    install -pd %{buildroot}%{_datadir}/icons/hicolor/$size/mimetypes
    install -pm0644 debian/qgis-mime-icon$size.png %{buildroot}%{_datadir}/icons/hicolor/$size/mimetypes/qgis-mime.png
done

install -pd %{buildroot}%{_datadir}/pixmaps
install -pd %{buildroot}%{_datadir}/icons/hicolor/scalable/apps

install -pm0644 images/icons/%{name}-icon.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
install -pm0644 images/icons/qbrowser-icon.png %{buildroot}%{_datadir}/pixmaps/qbrowser.png
install -pm0644 images/icons/%{name}-mime-icon.png %{buildroot}%{_datadir}/pixmaps/%{name}-mime.png
install -pm0644 images/icons/%{name}_icon.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
install -pm0644 images/icons/qbrowser_icon.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/qbrowser.svg
install -pm0644 images/icons/%{name}_icon.svg %{buildroot}%{_datadir}/pixmaps/%{name}.svg
install -pm0644 images/icons/qbrowser_icon.svg %{buildroot}%{_datadir}/pixmaps/qbrowser.svg

# Install basic QGIS Mapserver configuration for Apache
install -pd %{buildroot}%{_sysconfdir}/httpd/conf.d
install -pm0644 %{SOURCE2} \
    %{buildroot}%{_sysconfdir}/httpd/conf.d/qgis-server.conf

# See qgis-server-README.fedora
rm -f %{buildroot}%{_libexecdir}/%{name}/wms_metadata.xml
rm -f %{buildroot}%{_libexecdir}/%{name}/admin.sld

# Remove install instructions
rm -f %{buildroot}%{_datadir}/%{name}/doc/INSTALL

%find_lang %{name} --with-qt


%check
# All tests basically run fine, but one fails using mock, while a different one fails when building with rpmbuild alone
#export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
#xvfb-run -a -n 1 -s "-screen 0 1280x1024x24 -dpi 96" make Experimental
#rm -f %{_bindir}%{name}_bench


%post
/sbin/ldconfig
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
touch --no-create %{_datadir}/mime/packages &> /dev/null || :

%postun
/sbin/ldconfig
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
    touch --no-create %{_datadir}/mime/packages &> /dev/null || :
    update-mime-database %{?fedora:-n} %{_datadir}/mime &> /dev/null || :
fi

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
update-mime-database %{?fedora:-n} %{_datadir}/mime &> /dev/null || :

%post grass -p /sbin/ldconfig

%postun grass -p /sbin/ldconfig

%post -n python2-qgis -p /sbin/ldconfig

%postun -n python2-qgis -p /sbin/ldconfig

%files -f %{name}.lang
%doc BUGS NEWS Exception_to_GPL_for_Qt.txt ChangeLog.gz
# QGIS shows the following files in the GUI, including the license text
%doc %{_datadir}/%{name}/doc/
%dir %{_datadir}/%{name}/i18n/
%lang(zh-Hans) %{_datadir}/%{name}/i18n/%{name}_zh-Hans.qm
%lang(zh-Hant) %{_datadir}/%{name}/i18n/%{name}_zh-Hant.qm
%{_libdir}/lib%{name}_app.so.*
%{_libdir}/lib%{name}_analysis.so.*
%{_libdir}/lib%{name}_core.so.*
%{_libdir}/lib%{name}_gui.so.*
%{_libdir}/lib%{name}_networkanalysis.so.*
%{_libdir}/%{name}/
%{_qt4_prefix}/plugins/sqldrivers/libqsqlspatialite.so
%{_bindir}/%{name}
%{_bindir}/qbrowser
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/qbrowser.1*
%dir %{_datadir}/%{name}/
%{_datadir}/mime/packages/qgis.xml
%{_datadir}/pixmaps/
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/icons/hicolor/*/mimetypes/*
%{_datadir}/applications/*%{name}.desktop
%{_datadir}/applications/qbrowser.desktop
%{_datadir}/%{name}/images/
%{_datadir}/%{name}/resources/
%{_datadir}/%{name}/svg/
%exclude %{_libdir}/libqgisgrass*.so.*
%exclude %{_libdir}/%{name}/plugins/libgrassprovider*.so
%exclude %{_libdir}/%{name}/plugins/libgrassrasterprovider*.so
%exclude %{_libdir}/%{name}/plugins/libgrassplugin*.so
%exclude %{_libdir}/%{name}/grass/

%files devel
%{_datadir}/%{name}/FindQGIS.cmake
%{_includedir}/%{name}/
%{_libdir}/lib%{name}*.so
%{?_qt4_plugindir}/designer/libqgis_customwidgets.so*

%files grass
%{_libdir}/lib%{name}grass*.so.*
%{_libdir}/%{name}/plugins/libgrassprovider*.so
%{_libdir}/%{name}/plugins/libgrassrasterprovider*.so
%{_libdir}/%{name}/plugins/libgrassplugin*.so
%{_libdir}/%{name}/grass/
%{_datadir}/%{name}/grass/

%files -n python2-qgis
%{_libdir}/libqgispython.so.*
%{_datadir}/%{name}/python/
%{python_sitearch}/%{name}/
%{python_sitearch}/PyQt4/uic/widget-plugins/
%exclude %{python_sitearch}/%{name}/server/
%exclude %{python_sitearch}/%{name}/_server.so

%files server
%doc src/server/admin.sld src/server/wms_metadata.xml %{name}-server-README.fedora
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}-server.conf
%{_libdir}/lib%{name}_server.so.*
%{_libexecdir}/%{name}/
%{python_sitearch}/%{name}/server/
%{python_sitearch}/%{name}/_server.so


%changelog
* Fri Oct 27 2017 Daniele Viganò <daniele@vigano.me> - 2.18.4-1
- New upstream release

* Mon Sep 25 2017 Daniele Viganò <daniele@vigano.me> - 2.18.13-2
- Remove SIP-4.19-related patch

* Mon Sep 25 2017 Daniele Viganò <daniele@vigano.me> - 2.18.13-1
- New upstream release

* Tue Aug 22 2017 Volker Froehlich <volker27@gmx.at> - 2.18.12-1
- Add patch to solve SIP-4.19-related build failure

* Sat Aug 19 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 2.18.11-4
- Python 2 binary package renamed to python2-qgis
  See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3

* Tue Jul 25 2017 Daniele Viganò <daniele@vigano.me> - 2.18.11-1
- New upstream release

* Mon Jul 17 2017 Daniele Viganò <daniele@vigano.me> - 2.18.10-6
- Rebuild for F26 GA
- Sync with Fedora upstream http://pkgs.fedoraproject.org/cgit/rpms/qgis.git

* Mon Jun 26 2017 Daniele Viganò <daniele@vigano.me> - 2.18.10-2
- Limit maximum number of concurrent make

* Mon Jun 26 2017 Daniele Viganò <daniele@vigano.me> - 2.18.10-1
- Fix an issue in the QGIS server httpd configuration
- New upstream release

* Mon May 29 2017 Daniele Viganò <daniele@vigano.me> - 2.18.9-1
- New upstream release

* Mon May 22 2017 Daniele Viganò <daniele@vigano.me> - 2.18.8-1
- New upstream release

* Wed Apr 26 2017 Daniele Viganò <daniele@vigano.me> - 2.18.7-1
- New upstream release

* Sun Apr 09 2017 Daniele Viganò <daniele@vigano.me> - 2.18.6-2
- Fix F26 builds

* Sun Apr 09 2017 Daniele Viganò <daniele@vigano.me> - 2.18.6-1
- New upstream release

* Fri Apr 07 2017 Daniele Viganò <daniele@vigano.me> - 2.18.5-2
- Build for F26

* Mon Mar 27 2017 Daniele Viganò <daniele@vigano.me> - 2.18.5-1
- New upstream release

* Wed Mar 01 2017 Sandro Mani <manisandro@gmail.com> - 2.18.4-2
- Add patch to fix FTBFS

* Wed Mar 01 2017 Daniele Viganò <daniele@vigano.me> - 2.18.4-1
- New upstream release

* Wed Feb 01 2017 Daniele Viganò <daniele@vigano.me> - 2.18.3-1
- New upstream release

* Fri Dec 16 2016 Volker Froehlich <volker27@gmx.at> - 2.18.2-1
- New upstream release

* Sat Nov 26 2016 Volker Froehlich <volker27@gmx.at> - 2.18.1-1
- New upstream release

* Sun Nov 20 2016 Volker Froehlich <volker27@gmx.at> - 2.18.0-2
- Add qca-ossl to Requires, as of BZ#1396818

* Fri Oct 21 2016 Volker Froehlich <volker27@gmx.at> - 2.18.0-1
- New upstream release

* Mon Sep 26 2016 Orion Poplawski <orion@cora.nwra.com> - 2.16.3-1
- Update to 2.16.3
- Add patch to fix qreal usage on arm

* Mon Sep 26 2016 Orion Poplawski <orion@cora.nwra.com> - 2.16.2-1
- Update to 2.16.2 (bug #1378240)
- Add patch to fix build on 64-bit machines
- Drop unused cmake options
- Move %%grass_version macro to grass-devel, make it an install requirement

* Mon Sep 26 2016 Dominik Mierzejewski <rpm@greysector.net> - 2.14.3-6
- rebuilt for matplotlib-2.0.0

* Thu Aug 11 2016 Volker Froehlich <volker27@gmx.at> - 2.14.3-5
- Replace dependency on PyQt4 with PyQt4-webkit, since webkit
  is in a sub-package now (BZ #1360485)

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.14.3-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Tue Jun 07 2016 Volker Froehlich <volker27@gmx.at> - 2.14.3-3
- Version bump to be newer than F24

* Mon Jun 06 2016 Volker Froehlich <volker27@gmx.at> - 2.14.3-2
- Move grass version to BR. This will avoid building with a
  different version than intended. The sub-package dependencies
  is taken care of by soname versions.

* Mon May 23 2016 Volker Froehlich <volker27@gmx.at> - 2.14.3-1
- New upstream release

* Wed Apr 20 2016 Volker Froehlich <volker27@gmx.at> - 2.14.1-2
- Change BR of qca to qca2 to make things easier in EPEL
- Rebuild for BZ #1327360
- Make the requires on grass match an exact version again

* Sun Mar 27 2016 Volker Froehlich <volker27@gmx.at> - 2.14.1-1
- New upstream release
- Resolve the false sub-package dependency of python on server

* Fri Mar 25 2016 Devrim Gündüz <devrim@gunduz.org> - 2.14.0-5
- Depend exclusively against GRASS => 7.0.3

* Thu Mar 17 2016 Devrim Gündüz <devrim@gunduz.org> - 2.14.0-4
- Rebuild for GRASS 7.0.3

* Wed Mar 16 2016 Volker Froehlich <volker27@gmx.at> - 2.14.0-3
- Build with Grass 7
- Remove Requires-filtering, hiding the dependency on libgsl

* Wed Mar  9 2016 Volker Froehlich <volker27@gmx.at> - 2.14.0-2
- Add patch for upstream issue #14402 (MSSQL)

* Sat Feb 27 2016 Volker Froehlich <volker27@gmx.at> - 2.14.0-1
- New upstream release
- Add PyYAML as BR and disable the use of the bundled version
- Be more explicit about the supported version of grass
- Install proper icons (BZ #1166977)
- Break the dependency of the base package on the python sub-package
- Add a new locale not found by find_lang

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.12.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Jan 23 2016 Volker Froehlich <volker27@gmx.at> - 2.12.3-1
- New upstream release

* Sat Dec 19 2015 Volker Froehlich <volker27@gmx.at> - 2.12.2-1
- New upstream release

* Fri Nov 27 2015 Volker Froehlich <volker27@gmx.at> - 2.12.1-1
- New upstream release

* Mon Oct 26 2015 Volker Froehlich <volker27@gmx.at> - 2.12.0-2
- Fix ARM build

* Sat Oct 24 2015 Volker Froehlich <volker27@gmx.at> - 2.12.0-1
- New upstream release
- Add qca BR

* Sun Jul 26 2015 Volker Froehlich <volker27@gmx.at> - 2.10.1-3
- Correct conditionals for spatialite support on PPC and Fedora
  (Thanks to Rafael Fonseca)

* Sun Jul 26 2015 Volker Froehlich <volker27@gmx.at> - 2.10.1-2
- Rebuild for GDAL 2.0

* Tue Jul 21 2015 Volker Fröhlich <volker27@gmx.at> - 2.10.1-1
- New upstream release

* Wed Jul  8 2015 Volker Fröhlich <volker27@gmx.at> - 2.10.0-1
- New upstream release
- Drop obsolete Grass CMake patch
- Add ARM build fix; Thanks again, Sandro Mani!
- Truncate the changelog a bit

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.8.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Jun  3 2015 Volker Fröhlich <volker27@gmx.at> - 2.8.2-1
- New upstream release

* Mon Apr 20 2015 Rex Dieter <rdieter@fedoraproject.org> 2.8.1-4
- rebuild (qscintilla)

* Wed Mar 11 2015 Devrim GÜNDÜZ <devrim@gunduz.org> - 2.8.1-3
- Rebuild for Proj 4.9.1

* Mon Mar  9 2015 Volker Fröhlich <volker27@gmx.at> - 2.8.1-2
- Add upstream patch to fix the build on ARM

* Sun Mar  8 2015 Volker Fröhlich <volker27@gmx.at> - 2.8.1-1
- New upstream release, remove included patch change
- Rename mapserver sub-package to server
- Add a new locale not found by find_lang
- Partly solve the icon file naming issue (BZ#1166977)

* Thu Feb 19 2015 Dave Johansen <davejohansen@gmail.com> 2.6.1-2
- Rebuild for gcc 5.0 C++ ABI change

* Fri Jan  2 2015 Dave Johansen <davejohansen@gmail.com> - 2.6.1-1
- Update to 2.6.1

* Sun Nov  2 2014 Volker Fröhlich <volker27@gmx.at> - 2.6.0-2
- Fix the build on ARMv7hl, thanks to Sandro Mani!
- Updated the removing of executable permissions from source code files
- Add qscintilla-python-devel as BR
- Don't build the dxf converter plug-in
- Remove the Python directory definitions that were necessary on EL5

* Sun Nov  2 2014 Volker Fröhlich <volker27@gmx.at> - 2.6.0-1
- New upstream release, drop obsolete patch, update the sip patch

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Tue Aug 12 2014 Rex Dieter <rdieter@fedoraproject.org> 2.4.0-6
- update mime scriptlet

* Sun Aug 10 2014 Devrim GÜNDÜZ <devrim@gunduz.org> - 2.4.0-5
- Rebuild against new grass

* Sat Aug  9 2014 Volker Fröhlich <volker27@gmx.at> - 2.4.0-4
- Rebuild for grass 6.4.4

* Mon Jul 28 2014 Volker Fröhlich <volker27@gmx.at> - 2.4.0-3
- Restore ARM build (Thanks to Sandro Mani for the patch!)

* Fri Jul 25 2014 Peter Robinson <pbrobinson@fedoraproject.org> 2.4.0-2
- rebuild (libspatialite)

* Sat Jun 28 2014 Volker Fröhlich <volker27@gmx.at> - 2.4.0-1
- New upstream release, drop obsolete patches, update remaining
- Remove references to "Quantum"
- Add CODING and BUGS file
- Add necessary direct Python module dependencies

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Mar 28 2014 Volker Fröhlich <volker27@gmx.at> - 2.2.0-3
- ARM build fix

* Sun Mar 16 2014 Rex Dieter <rdieter@fedoraproject.org> 2.2.0-2
- rebuild (sip)

* Sat Feb 22 2014 Volker Fröhlich <volker27@gmx.at> - 2.2.0-1
- New upstream release
- Fix the issue of the license text not being shown in the GUI
- Drop EL5 support leftovers
- Remove private provides
- Remove unnecessary explicit paths for GDAL
- Simplify conditionals
- Remove custom plugin directory setting
- Delete bundled Pyspatialite
- Compress changelog file
- Simplify documentation labeling

* Fri Feb 07 2014 Volker Fröhlich <volker27@gmx.at> - 2.0.1-8
- Rebuild for minor ABI breakage in spatialindex 1.8.1

* Wed Dec 25 2013 Volker Fröhlich <volker27@gmx.at> - 2.0.1-7
- Python sub-package must require psycopg2 for the Processing plug-in
  (BZ #1043683)

* Fri Nov 08 2013 Volker Fröhlich <volker27@gmx.at> - 2.0.1-6
- Rebuild for new qwt and qwtpolar

* Sat Oct 19 2013 Volker Fröhlich <volker27@gmx.at> - 2.0.1-5
- Patch QGIS #8507 -- QGIS trunk failed to compile with sip 4.15
- Patch QGIS #8601 -- sip: QgsFieldValidator::fixup has versioned and
  unversioned overloads

* Wed Oct 16 2013 Rex Dieter <rdieter@fedoraproject.org> 2.0.1-4
- rebuild (sip)

* Tue Oct  1 2013 Volker Fröhlich <volker27@gmx.at> - 2.0.1-3
- Fix Grass version to make breakage more visible

* Fri Sep 27 2013 Volker Fröhlich <volker27@gmx.at> - 2.0.1-2
- Remove import path for httplib2 module to use the system version
- Use upstream desktop files

* Wed Sep 25 2013 Volker Fröhlich <volker27@gmx.at> - 2.0.1-1
- New upstream release
- Exclude ARM for now, due to build issues

* Sat Sep 14 2013 Volker Fröhlich <volker27@gmx.at> - 1.8.0-17
- Rebuild for grass 6.4.3

* Tue Aug 27 2013 Orion Poplawski <orion@cora.nwra.com> - 1.8.0-16
- Rebuild for gdal 1.10.0

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.0-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Jun 17 2013 Rex Dieter <rdieter@fedoraproject.org> 1.8.0-14
- rebuild (sip)

* Fri Feb 22 2013 Toshio Kuratomi <toshio@fedoraproject.org> - 1.8.0-13
- Remove --vendor from desktop-file-install https://fedorahosted.org/fesco/ticket/1077

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.0-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Dec 15 2012 Volker Fröhlich <volker27@gmx.at> - 1.8.0-11
- Rebuild for spatialindex soname bump

* Sun Dec  2 2012 Bruno Wolff III <bruno@wolff.to> - 1.8.0-10
- Rebuild for libspatialite soname bump

* Thu Nov  8 2012 Volker Fröhlich <volker27@gmx.at> - 1.8.0-9
- Build with system version of qextserialport
- Update config file to fit httpd 2.4 (BZ#871471)

* Wed Oct 03 2012 Rex Dieter <rdieter@fedoraproject.org> 1.8.0-8
- rebuild (sip)

* Thu Aug  9 2012 Volker Fröhlich <volker27@gmx.at> - 1.8.0-7
- Append ppc to ppc64 conditionals

* Wed Jul 18 2012 Volker Fröhlich <volker27@gmx.at> - 1.8.0-6
- Add patch for QGIS bug #5809

* Sat Jul  7 2012 Volker Fröhlich <volker27@gmx.at> - 1.8.0-5
- Rebuilt too quick

* Sat Jul  7 2012 Volker Fröhlich <volker27@gmx.at> - 1.8.0-4
- One more rebuild, due to a broken GDAL

* Fri Jul  6 2012 Volker Fröhlich <volker27@gmx.at> - 1.8.0-3
- Rebuild for Spatialite 3

* Thu Jul  5 2012 Volker Fröhlich <volker27@gmx.at> - 1.8.0-2
- Correct locale if clause
- Apply patch for older versions of SIP

* Fri Jun 29 2012 Volker Fröhlich <volker27@gmx.at> - 1.8.0-1
- New upstream release
- Correct provides-filtering as of https://fedoraproject.org/wiki/Packaging:AutoProvidesAndRequiresFiltering#Usage
- Drop obsolete spatialindex patch
- FSF addresses are now correct
- Explicitly set PYSPATIALITE to false
- Don't ship the 4 MB changelog
- Use wildcard for soname versions

* Tue Apr 10 2012 Volker Fröhlich <volker27@gmx.at> - 1.7.4-4
- Been to quick with rebuilding, proper spatialindex build wasn't used yet

* Mon Apr  9 2012 Volker Fröhlich <volker27@gmx.at> - 1.7.4-3
- Apply patch for Spatialindex 1.7's include dir
- Rebuild for Spatialindex 1.7.1

* Fri Mar 23 2012 Volker Fröhlich <volker27@gmx.at> - 1.7.4-2
- Rebuild for GRASS 6.4.2

* Sun Feb 19 2012 Volker Fröhlich <volker27@gmx.at> - 1.7.4-1
- Update for new release

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sat Dec 10 2011 Volker Fröhlich <volker27@gmx.at> - 1.7.3-1
- Update for new release
- Is also the rebuild for BZ#761147
- Arch-specifically require the base package

* Tue Nov 15 2011 Volker Fröhlich <volker27@gmx.at> - 1.7.2-1
- Updated for new release
- No more themes directory
- Remove dispensable geo-referencing patch

* Sun Oct 16 2011 Volker Fröhlich <volker27@gmx.at> - 1.7.1-2
- Findlang doesn't recognize sr@latin in Fedora 14 and older
- Build with system-wide spatialindex
- Remove if structures intended for EPEL package
  Due to the rapid development in QGIS and the libraries it uses,
  QGIS will not go to EPEL now; ELGIS provides rebuilds with more
  current versions: http://elgis.argeo.org/

* Sat Sep 24 2011 Volker Fröhlich <volker27@gmx.at> - 1.7.1-1
- Update for new release
- Drop one patch that made it into the release
- Correct permissions for two cpp files
- Change spelling for changelog file
- Findlang seems to find sr@latin now, so don't explicitly list it
- Build with Qwtpolar
- Remove grass as BR
- Add GRASS_PREFIX again
  Cmake uses the first entry in FindGRASS.cmake,
  which is not fine for 64 bit systems

* Sun Jul 24 2011 Volker Fröhlich <volker27@gmx.at> - 1.7.0-5
- Extend histogram patch, see BZ 725161

* Wed Jul 06 2011 Volker Fröhlich <volker27@gmx.at> - 1.7.0-4
- Remove icon path macros, that don't work in EPEL
- Avoid creating unnecessary directories there
- Be explicit about the shared lib names in the files section
- Put libqgispython.so.1.7.0 in Python sub-package
- Correct FSF address

* Wed Jul 06 2011 Volker Fröhlich <volker27@gmx.at> - 1.7.0-3
- Withdraw immature Lighty configuration
- Update README and provide a better sample configuration,
  that utilizes mod_rewrite

* Sun Jun 26 2011 Volker Fröhlich <volker27@gmx.at> - 1.7.0-2
- Add histogram patch
- Add scriplets to refresh icon cache
- Mention Fedora specific readme file in QGIS mapserver description
- Update the aforementioned file and the Apache configuration
  with rewrite rules

* Sun Jun 26 2011 Volker Fröhlich <volker27@gmx.at> - 1.7.0-1
- Update for 1.7
- License is now GPLv3+ (Sqlanyconnect)
- Add mapserver sub-package and require mod_fcgi
- Use upstreams current description text
- Drop now needless iconv
- Rename new Serbian translations
- Install MIME type definitions and icons
- Add Readme file and sample configuration for Mapserver
- Add patch to avoid segfault when geo-referencing
- Add conditional for Spatialite and PPC64
- Add conditional for GRASS and EPEL
- Delete bundled libspatialite before building
- Removed glob from /usr/bin/qgis in files section
